package cn.com.infosec.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.GeneralName;
import cn.com.infosec.asn1.x509.GeneralNames;
import cn.com.infosec.asn1.x509.Holder;
import cn.com.infosec.asn1.x509.IssuerSerial;
import cn.com.infosec.asn1.x509.ObjectDigestInfo;
import cn.com.infosec.jce.PrincipalUtil;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.util.Arrays;
import cn.com.infosec.util.Selector;
import java.io.IOException;
import java.math.BigInteger;
import java.security.MessageDigest;
import java.security.Principal;
import java.security.cert.CertSelector;
import java.security.cert.Certificate;
import java.security.cert.CertificateEncodingException;
import java.security.cert.CertificateParsingException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import javax.security.auth.x500.X500Principal;

public class AttributeCertificateHolder implements CertSelector, Selector {
   final Holder holder;

   AttributeCertificateHolder(ASN1Sequence seq) {
      this.holder = Holder.getInstance(seq);
   }

   public AttributeCertificateHolder(X509Principal issuerName, BigInteger serialNumber) {
      AttributeCertificateHolder var10000 = this;
      super();
      Holder var7;
      Holder var10001 = var7 = new Holder;
      IssuerSerial var3;
      IssuerSerial var10002 = var3 = new IssuerSerial;
      GeneralNames var4;
      GeneralNames var10003 = var4 = new GeneralNames;
      DERSequence var5;
      DERSequence var10004 = var5 = new DERSequence;
      GeneralName var6;
      var6 = new GeneralName.<init>(issuerName);
      var10004.<init>(var6);
      var10003.<init>(var5);
      DERInteger issuerName1;
      issuerName1 = new DERInteger.<init>(serialNumber);
      var10002.<init>(var4, issuerName1);
      var10001.<init>(var3);
      var10000.holder = var7;
   }

   public AttributeCertificateHolder(X500Principal issuerName, BigInteger serialNumber) {
      this(X509Util.convertPrincipal(issuerName), serialNumber);
   }

   public AttributeCertificateHolder(X509Certificate cert) {
      X509Certificate var10001 = cert;
      super();

      X509Principal var4;
      try {
         var4 = PrincipalUtil.getIssuerX509Principal(var10001);
      } catch (Exception var3) {
         throw new CertificateParsingException(var3.getMessage());
      }

      X509Principal var2 = var4;
      this.holder = new Holder(new IssuerSerial(this.generateGeneralNames(var2), new DERInteger(cert.getSerialNumber())));
   }

   public AttributeCertificateHolder(X509Principal principal) {
      this.holder = new Holder(this.generateGeneralNames(principal));
   }

   public AttributeCertificateHolder(X500Principal principal) {
      this(X509Util.convertPrincipal(principal));
   }

   public AttributeCertificateHolder(int digestedObjectType, String digestAlgorithm, String otherObjectTypeID, byte[] objectDigest) {
      AttributeCertificateHolder var10000 = this;
      super();
      Holder var6;
      Holder var10001 = var6 = new Holder;
      ObjectDigestInfo var5;
      ObjectDigestInfo var10002 = var5 = new ObjectDigestInfo;
      byte[] var10003 = objectDigest;
      AlgorithmIdentifier objectDigest1;
      objectDigest1 = new AlgorithmIdentifier.<init>(digestAlgorithm);
      byte[] digestAlgorithm1 = Arrays.clone(var10003);
      var10002.<init>(digestedObjectType, otherObjectTypeID, objectDigest1, digestAlgorithm1);
      var10001.<init>(var5);
      var10000.holder = var6;
   }

   private GeneralNames generateGeneralNames(X509Principal principal) {
      DERSequence var3;
      DERSequence var10002 = var3 = new DERSequence;
      GeneralName var2;
      var2 = new GeneralName.<init>(principal);
      var10002.<init>(var2);
      return new GeneralNames(var3);
   }

   private boolean matchesDN(X509Principal subject, GeneralNames targets) {
      GeneralName[] var6 = targets.getNames();

      for(int targets1 = 0; targets1 != var6.length; ++targets1) {
         GeneralName var3;
         if ((var3 = var6[targets1]).getTagNo() == 4) {
            X509Principal var10000;
            boolean var10001;
            try {
               var10000 = new X509Principal;
            } catch (IOException var5) {
               var10001 = false;
               continue;
            }

            X509Principal var9 = var10000;

            boolean var8;
            try {
               var9.<init>(((ASN1Encodable)var3.getName()).getEncoded());
               var8 = var10000.equals(subject);
            } catch (IOException var4) {
               var10001 = false;
               continue;
            }

            if (var8) {
               return true;
            }
         }
      }

      return false;
   }

   private Object[] getNames(GeneralName[] names) {
      ArrayList var4;
      var4 = new ArrayList.<init>(names.length);

      for(int var2 = 0; var2 != names.length; ++var2) {
         if (names[var2].getTagNo() == 4) {
            try {
               var4.add(new X500Principal(((ASN1Encodable)names[var2].getName()).getEncoded()));
            } catch (IOException var3) {
               throw new RuntimeException("badly formed Name object");
            }
         }
      }

      return var4.toArray(new Object[var4.size()]);
   }

   private Principal[] getPrincipals(GeneralNames names) {
      Object[] var3 = this.getNames(names.getNames());
      ArrayList names1;
      names1 = new ArrayList.<init>();

      for(int var2 = 0; var2 != var3.length; ++var2) {
         if (var3[var2] instanceof Principal) {
            names1.add(var3[var2]);
         }
      }

      return (Principal[])names1.toArray(new Principal[names1.size()]);
   }

   public int getDigestedObjectType() {
      return this.holder.getObjectDigestInfo() != null ? this.holder.getObjectDigestInfo().getDigestedObjectType().getValue().intValue() : -1;
   }

   public String getDigestAlgorithm() {
      if (this.holder.getObjectDigestInfo() != null) {
         this.holder.getObjectDigestInfo().getDigestAlgorithm().getObjectId().getId();
      }

      return null;
   }

   public byte[] getObjectDigest() {
      if (this.holder.getObjectDigestInfo() != null) {
         this.holder.getObjectDigestInfo().getObjectDigest().getBytes();
      }

      return null;
   }

   public String getOtherObjectTypeID() {
      if (this.holder.getObjectDigestInfo() != null) {
         this.holder.getObjectDigestInfo().getOtherObjectTypeID().getId();
      }

      return null;
   }

   public Principal[] getEntityNames() {
      return this.holder.getEntityName() != null ? this.getPrincipals(this.holder.getEntityName()) : null;
   }

   public Principal[] getIssuer() {
      return this.holder.getBaseCertificateID() != null ? this.getPrincipals(this.holder.getBaseCertificateID().getIssuer()) : null;
   }

   public BigInteger getSerialNumber() {
      return this.holder.getBaseCertificateID() != null ? this.holder.getBaseCertificateID().getSerial().getValue() : null;
   }

   public Object clone() {
      return new AttributeCertificateHolder((ASN1Sequence)this.holder.toASN1Object());
   }

   public boolean match(Certificate cert) {
      if (!(cert instanceof X509Certificate)) {
         return false;
      } else {
         AttributeCertificateHolder var10000 = this;
         X509Certificate var2 = (X509Certificate)cert;

         IssuerSerial var16;
         boolean var10001;
         try {
            var16 = var10000.holder.getBaseCertificateID();
         } catch (CertificateEncodingException var14) {
            var10001 = false;
            return false;
         }

         boolean var17;
         if (var16 != null) {
            try {
               var17 = this.holder.getBaseCertificateID().getSerial().getValue().equals(var2.getSerialNumber());
            } catch (CertificateEncodingException var6) {
               var10001 = false;
               return false;
            }

            if (var17) {
               try {
                  var17 = this.matchesDN(PrincipalUtil.getIssuerX509Principal(var2), this.holder.getBaseCertificateID().getIssuer());
               } catch (CertificateEncodingException var5) {
                  var10001 = false;
                  return false;
               }

               if (var17) {
                  return true;
               }
            }

            return false;
         } else {
            GeneralNames var18;
            try {
               var18 = this.holder.getEntityName();
            } catch (CertificateEncodingException var13) {
               var10001 = false;
               return false;
            }

            if (var18 != null) {
               try {
                  var17 = this.matchesDN(PrincipalUtil.getSubjectX509Principal(var2), this.holder.getEntityName());
               } catch (CertificateEncodingException var12) {
                  var10001 = false;
                  return false;
               }

               if (var17) {
                  return true;
               }
            }

            ObjectDigestInfo var19;
            try {
               var19 = this.holder.getObjectDigestInfo();
            } catch (CertificateEncodingException var11) {
               var10001 = false;
               return false;
            }

            if (var19 != null) {
               MessageDigest var21;
               try {
                  var10000 = this;
                  var21 = MessageDigest.getInstance(this.getDigestAlgorithm(), "INFOSEC");
               } catch (Exception var4) {
                  return false;
               }

               MessageDigest var15 = var21;

               int var20;
               try {
                  var20 = var10000.getDigestedObjectType();
               } catch (CertificateEncodingException var10) {
                  var10001 = false;
                  return false;
               }

               int var3 = var20;
               if (var20 != 0) {
                  if (var3 == 1) {
                     try {
                        var15.update(cert.getEncoded());
                     } catch (CertificateEncodingException var9) {
                        var10001 = false;
                        return false;
                     }
                  }
               } else {
                  try {
                     var15.update(cert.getPublicKey().getEncoded());
                  } catch (CertificateEncodingException var8) {
                     var10001 = false;
                     return false;
                  }
               }

               try {
                  var17 = Arrays.areEqual(var15.digest(), this.getObjectDigest());
               } catch (CertificateEncodingException var7) {
                  var10001 = false;
                  return false;
               }

               if (!var17) {
                  return false;
               }
            }

            return false;
         }
      }
   }

   public boolean equals(Object obj) {
      if (obj == this) {
         return true;
      } else if (!(obj instanceof AttributeCertificateHolder)) {
         return false;
      } else {
         AttributeCertificateHolder var10000 = this;
         AttributeCertificateHolder var2 = (AttributeCertificateHolder)obj;
         return var10000.holder.equals(var2.holder);
      }
   }

   public int hashCode() {
      return this.holder.hashCode();
   }

   public boolean match(Object obj) {
      return !(obj instanceof X509Certificate) ? false : this.match((Certificate)obj);
   }
}
